@@ -2,16 +2,13 @@
 
 package ZeroMQ::PubSub::Server;
 
-use Any::Moose;
+use Moose;
 extends 'ZeroMQ::PubSub';
 
 use ZeroMQ qw/:all/;
 use Clone qw/clone/;
 use Carp qw/croak/;
 
-#use Any::Moose 'X::Event';
-use MooseX::Event;
-
 # socket to listen for client events
 # clients publish events to us here
 sub _build_publish_sock {
